==> AGXUnreal-1.17.0_UE-5.5_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics/Signals/RealRangeInputSignal.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/Signals/InputSignal.h>
#include <openplx/Math/Vec2.h>
#include <openplx/Physics/Signals/Input.h>
/* Generated code for model RealRangeInputSignal */
namespace openplx::Physics::Signals {
    class RealRangeInputSignal : public openplx::Physics::Signals::InputSignal {
        protected:
            std::shared_ptr<openplx::Math::Vec2> m_value;

        public:
            RealRangeInputSignal();
            std::shared_ptr<openplx::Math::Vec2> value() const;
            static std::shared_ptr<openplx::Physics::Signals::RealRangeInputSignal> create(std::shared_ptr<openplx::Math::Vec2> value, std::shared_ptr<openplx::Physics::Signals::Input> target);
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.7_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics/Signals/RealRangeInputSignal.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics/PhysicsBundleExport.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/Signals/InputSignal.h>
#include <openplx/Math/Vec2.h>
#include <openplx/Physics/Signals/Input.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model RealRangeInputSignal */
namespace openplx::Physics::Signals {
    class OPENPLX_Physics_BUNDLE_EXPORT RealRangeInputSignal : public openplx::Physics::Signals::InputSignal {
        protected:
            std::shared_ptr<openplx::Math::Vec2> m_value;

        public:
            RealRangeInputSignal();
            virtual ~RealRangeInputSignal();
            std::shared_ptr<openplx::Math::Vec2> value() const;
            static std::shared_ptr<openplx::Physics::Signals::RealRangeInputSignal> create(std::shared_ptr<openplx::Math::Vec2> value, std::shared_ptr<openplx::Physics::Signals::Input> target);
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
